@@ -47,7 +47,10 @@ impl AgentClient<tokio::net::UnixStream> {
         } else {
             return Err(Error::EnvVar("SSH_AUTH_SOCK"));
         };
-        Self::connect_uds(var).await
+        match Self::connect_uds(var).await {
+            Err(Error::IO(io_err)) if io_err.kind() == std::io::ErrorKind::NotFound => Err(Error::BadAuthSock),
+            owise => owise
+        }
     }
 }
 
